from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

import time
import os
import commands
import libdesklets

class LTVDisk(Sensor):

	def __init__(self, default_mntpoint = "/", default_icon = "hd", interval = "10", snap = "1"):
		
		global _; _ = i18n.Translator("ltv-disk-sensor")
		
		self.__free = ""
		self.__used = ""
		self.__total = ""
		self.__status = ""
		self.__percent = 0
		self.__percentsnap = 0
		self.__mounted = ""
		self.__targets = []
		self.__icons = [[_("Hard Disk"),"hd"],[_("Home"),"home"],[_("Directory"),"directory"],[_("Files"),"files"],[_("Floppy Disk"),"floppy"],[_("CD-ROM"),"cdrom"],[_("Network"),"network"]]
		self.__snap = float(snap)
		Sensor.__init__(self)
		
		self._set_config_type("update", TYPE_INT, int(interval))
		self._set_config_type("target", TYPE_STRING, default_mntpoint)
		self._set_config_type("icon", TYPE_STRING, default_icon)
		self._set_config_type("cut_mnt", TYPE_BOOL, 1)
		
		self._add_timer(0, self.disk_loop)
		self._watch_config(self.watch_config)
		
		for i in libdesklets.disk.get_partitions():
			self.__targets += [[ i[ 0 ] + " : " + i[ 1 ], i[ 1 ] ]]

	def get_configurator(self):
		configurator = self._new_configurator()
		configurator.set_name(_("Disk usage"))
		configurator.add_title(_("Display Configuration"))
		configurator.add_spin(_("Update every (ds):"), "update", _("Updates the disk usage every x deciseconds"), 1, 600)
		configurator.add_option(_("Icon:"), "icon", _("Icon to use"),self.__icons)
		configurator.add_option(_("Target:"), "target", _("Possible targets"),self.__targets)
		configurator.add_checkbox(_("Remove '/mnt/'"), "cut_mnt", _("Removes the '/mnt/' from the beginning of names so it looks nicer."))
		return configurator
	
	def refresh(self):
			sizes = libdesklets.disk.get_size( self._get_config("target") )

			self.__total = sizes[ 0 ]
			self.__used = sizes[ 1 ]
			self.__free = sizes[ 0 ] - sizes[ 1 ]
			self.__percent = int(round( 100 * sizes[ 1 ] / sizes[ 0 ] ))
			self.__snap = self.__snap * int( 100 * sizes[ 1 ] / sizes[ 0 ] / self.__snap )

			self.__status = str( self.__percent ) + "%"
				
			data = self._new_output()

			data.set("total", self.__total)
			data.set("used", self.__used)
			data.set("free", self.__free)
			data.set("percent", self.__percent)
			data.set("status", self.__status)
			data.set("snap", self.__snap)

			data.set("icon", "gfx/disk-" + self._get_config("icon") + ".png")
			if self._get_config("cut_mnt"):
				data.set("name",self._get_config("target").replace("/mnt/",""))
			else:
				data.set("name",self._get_config("target"))
			self._send_output(data)

	def disk_loop(self):
		self.refresh( )
		self._add_timer(self._get_config("update")*100, self.disk_loop)
	
	def watch_config(self,key,value):
		self.refresh()

def new_sensor(args): return apply(LTVDisk, args)
