from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

from libdesklets import glibtop

class LTVMemory(Sensor):

	def __init__(self, interval = "10", snap = "1"):
		global _; _ = i18n.Translator("ltv-memory-sensor")
		self.__snap = float(snap)
		Sensor.__init__(self)
		self._set_config_type("update", TYPE_INT, int(interval))
		self._add_timer(0, self.memory_loop)

	def get_configurator(self):
		configurator = self._new_configurator()
		configurator.set_name(_("Memory monitor"))
		configurator.add_title(_("Display Configuration"))
		configurator.add_spin(_("Update every (ds):"), "update", _("Updates the display every x deciseconds"), 1, 600)
		return configurator
	
	def memory_loop(self):
		mem = glibtop.get_mem()
			
		total = int(mem[ 0 ]/1024/1024)
		used = int(mem[ 1 ]/1024/1024)
		real = int(mem[ 6 ]/1024/1024)
		percent_used = int( 100 * used / total )
		snapped_used = self.__snap * int( percent_used / self.__snap )
		percent = int( 100 * real / total )
		snapped = self.__snap * int( percent / self.__snap )
			
		data = self._new_output( )
		data.set("percent", percent)
		data.set("percent_used", percent_used)
		data.set("snap", snapped)
		data.set("snap_used", snapped_used)
		data.set("used", str(real) + _("MB") )
		data.set("free", str(total - real) + _("MB") )
		data.set("total", str(total) + _("MB") )
		self._send_output(data)
		self._add_timer(self._get_config("update")*100, self.memory_loop)

def new_sensor(args): return apply(LTVMemory, args)
